<?php
/**
 * Featured Post Element.
 *
 * Please do not edit this file. This file is part of the Cyber Chimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category Cyber Chimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */

// Don't load directly
if( !defined( 'ABSPATH' ) ) {
	die( '-1' );
}

// Action for Featured Posts
add_action( 'featured_posts', 'cyberchimps_featured_posts_content' );

function cyberchimps_featured_posts_content() {
	global $post; // call globals

	// Getting featured post option values
	if( is_page() ) {
		$post_category = ( get_post_meta( $post->ID, 'cyberchimps_featured_post_category_toggle', true ) == 1 ) ? get_post_meta( $post->ID, 'cyberchimps_featured_post_category', true ) : '';
	}
	else {
		$post_category = ( cyberchimps_get_option( 'featured_posts_categories' ) == 'all' ) ? '' : get_the_category_by_ID( cyberchimps_get_option( 'featured_posts_categories' ) );
		$post_category = ( is_wp_error( $post_category ) ) ? '' : $post_category;
	}
	?>
	<div class="row-fluid featured-posts">
		<div class="featured-posts-container">
			<div class="span8">
				<div id="featured_post">
					<ul>
						<?php
						/* To keep the post ids for those are already displayed */
						$exclude_posts = array();

						$counter = 1;

						$the_query = new WP_Query( array( 'showposts'    => -1, 'category_name' => $post_category,
						                                  'orderby'      => 'post_date', 'order' => 'desc',
						                                  'post__not_in' => get_option( 'sticky_posts' )
						                           ) );
						if( $the_query->have_posts() ) : while( $the_query->have_posts() ) : $the_query->the_post();
							$exclude_posts[] = get_the_ID();

							$class = "featured" . $counter;
							$counter++;
							?>
							<li class="<?php echo $class; ?>">
								<div class="featured-post-meta">
									<span><?php echo get_the_time( 'F j, Y' ); ?></span> |
									<span><?php comments_popup_link( 'No Comment', '1 Comment', '% Comments' ); ?></span>
								</div>
								<?php if( has_post_thumbnail() ) { ?>
									<a href="<?php the_permalink() ?>" class="headline-link headline-left">
										<?php the_post_thumbnail( 'headline-thumb', array( 'class' => 'headline-thumb' ) ); ?>
									</a>
								<?php } ?>
								<h2 class="title"><a rel="bookmark" href="<?php the_permalink() ?>"><?php the_title(); ?></a></h2>

								<div class="clear"></div>
								<?php
								add_filter( 'excerpt_more', 'cyberchimps_featured_post_excerpt_more' );
								add_filter( 'excerpt_length', 'cyberchimps_featured_post_length', 999 );
								the_excerpt();
								remove_filter( 'excerpt_more', 'cyberchimps_featured_post_excerpt_more' );
								remove_filter( 'excerpt_length', 'cyberchimps_featured_post_length', 999 );
								?>
							</li>
						<?php
						endwhile;
							wp_reset_query();
						endif
						?>
					</ul>
				</div>
			</div>
			<div class="span4">
				<div id="featured_list">
					<ul id="mycarousel" class="jcarousel jcarousel-skin-response">
						<?php
						$counter = 1;
						$featured_query = new WP_Query( array( 'showposts'    => -1, 'category_name' => $post_category,
						                                       'orderby'      => 'post_date', 'order' => 'desc',
						                                       'post__not_in' => get_option( 'sticky_posts' )
						                                ) );
						if( $featured_query->have_posts() ) :
							while( $featured_query->have_posts() ) : $featured_query->the_post();
								$id = "featured" . $counter;
								$counter++;
								?>
								<li id="<?php echo $id; ?>">
									<div class="row-fluid">
										<div class="featured-list-item">
											<div class="span4">
												<?php
												if( has_post_thumbnail() ) {
													the_post_thumbnail( 'featured-thumb', array( 'class' => 'featured-list-thumb' ) );
												}?>
											</div>
											<div class="span8">
												<div class="featured-list-info">
													<h5><?php the_title(); ?></h5>

													<div class="featured-list-meta">
														<span class="date-n-time"><?php echo get_the_time( 'F j, Y' ); ?></span>
														<span class="comments-n-views"><?php comments_popup_link( 'No Comment', '1 Comment', '% Comments' ); ?></span>
													</div>
												</div>
											</div>
											<!-- span8 -->
										</div>
										<!-- featured-list-item -->
									</div>
									<!-- row-fluid -->
								</li>
							<?php endwhile;
							wp_reset_query();
						endif ?>
					</ul>
				</div>
			</div>
			<div class="clear"></div>
		</div>
	</div>


<?php
}

?>