<?php
/**
 * Element Initializer
 *
 * Please do not edit this file. This file is part of the Cyber Chimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category Cyber Chimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */

// Load style for elements
function cyberchimps_add_elements_scripts() {

	// Set path of library
	$path_lib = get_template_directory_uri() . '/elements/lib/';

	// Add JS for elastislide library to be used for carousel element.
	wp_register_script( 'elastislide', $path_lib . 'js/jquery.elastislide.min.js', array( 'jquery' ), 1, true );
	wp_enqueue_script( 'elastislide' );

	wp_register_style( 'elements_style', $path_lib . 'css/elements.css' );
	wp_enqueue_style( 'elements_style' );

	wp_register_style( 'jcarousel-skin', $path_lib . 'css/jcarousel/skin.css' );
	wp_enqueue_style( 'jcarousel-skin', array( 'bootstrap-responsive-style', 'bootstrap-style' ), '1.0' );

	wp_register_script( 'elements_js', $path_lib . 'js/elements.min.js', array( 'jquery' ), '2013.12.12', true );
	wp_enqueue_script( 'elements_js' );
}

add_action( 'wp_enqueue_scripts', 'cyberchimps_add_elements_scripts', 19 );

// Set path of element folder.
$path_elements = get_template_directory() . '/elements/';

// Load elements
require_once( $path_elements . 'widgets.php' );
require_once( $path_elements . 'breadcrumbs.php' );
require_once( $path_elements . 'callout.php' );
require_once( $path_elements . 'carousel.php' );
require_once( $path_elements . 'htmlbox.php' );
require_once( $path_elements . 'magazine.php' );
require_once( $path_elements . 'pagination.php' );
require_once( $path_elements . 'portfolio.php' );
require_once( $path_elements . 'product.php' );
require_once( $path_elements . 'slider.php' );
require_once( $path_elements . 'twitter-bar.php' );
require_once( $path_elements . 'recent-posts.php' );
require_once( $path_elements . 'boxes.php' );
//require_once( $path_elements . 'profile.php' );
//require_once( $path_elements . 'featured-posts.php' );

// Load shortcodes
require_once( $path_elements . 'shortcodes/init.php' );

function cyberchimps_selected_elements() {
	$options = array(
		'boxes'              => __( 'Boxes', 'cyberchimps_elements' ),
		"callout_section"    => __( 'Callout Section', 'cyberchimps_elements' ),
		"carousel_section"   => __( 'Carousel', 'cyberchimps_elements' ),
		//'featured_posts'		=> __( 'Featured Posts', 'cyberchimps_elements' ),
		'html_box'           => __( 'HTML Box', 'cyberchimps_elements' ),
		'page_slider'        => __( 'iFeature Slider', 'cyberchimps_elements' ),
		'magazine'				=> __( 'Magazine', 'cyberchimps_elements' ),
		'portfolio_pro'      => __( 'Portfolio', 'cyberchimps_elements' ),
		"blog_post_page"     => __( 'Post Page', 'cyberchimps_elements' ),
		"product_element"    => __( 'Product', 'cyberchimps_elements' ),
		//"profile"				=> __( 'Profile', 'cyberchimps_elements' ),
		'recent_posts'       => __( 'Recent Posts', 'cyberchimps_elements' ),
		"twitterbar_section" => __( 'Twitter Bar', 'cyberchimps_elements' ),
		"widgets_section"    => __( 'Widgets', 'cyberchimps_elements' )
	);

	return $options;
}

add_filter( 'cyberchimps_elements_draganddrop_options', 'cyberchimps_selected_elements', 2 );

//set defaults elements for page draga and drop
function cyberchimps_selected_page_elements() {
	$options = array(
		'boxes'              => __( 'Boxes', 'cyberchimps_elements' ),
		'breadcrumbs'        => __( 'Breadcrumbs', 'cyberchimps_elements' ),
		"callout_section"    => __( 'Callout Section', 'cyberchimps_elements' ),
		"carousel_section"   => __( 'Carousel', 'cyberchimps_elements' ),
		//'featured_posts'		=> __( 'Featured Posts', 'cyberchimps_elements' ),
		'html_box'           => __( 'HTML Box', 'cyberchimps_elements' ),
		'page_slider'        => __( 'iFeature Slider', 'cyberchimps_elements' ),
		'magazine'				=> __( 'Magazine', 'cyberchimps_elements' ),
		'portfolio_pro'      => __( 'Portfolio', 'cyberchimps_elements' ),
		"page_section"       => __( 'Page', 'cyberchimps_elements' ),
		"product_element"    => __( 'Product', 'cyberchimps_elements' ),
		//"profile"				=> __( 'Profile', 'cyberchimps_elements' ),
		'recent_posts'       => __( 'Recent Posts', 'cyberchimps_elements' ),
		"twitterbar_section" => __( 'Twitter Bar', 'cyberchimps_elements' ),
		"widgets_section"    => __( 'Widgets', 'cyberchimps_elements' )
	);

	return $options;
}

add_filter( 'cyberchimps_elements_draganddrop_page_options', 'cyberchimps_selected_page_elements', 2 );